@@ -599,6 +599,8 @@ ORBit_small_invoke_stub (CORBA_Object       obj,
 		goto clean_out;
 	}
 
+	CORBA_exception_init (ev);
+
 	if ((invoke_policy = ORBit_object_get_policy (obj)))
 		ORBit_policy_push (invoke_policy);
 
@@ -606,7 +608,8 @@ ORBit_small_invoke_stub (CORBA_Object       obj,
 
 	if (adaptor_obj) {
 		/* FIXME: unchecked cast */
-		if (ORBit_poa_allow_cross_thread_call ((ORBit_POAObject) adaptor_obj)) {
+		if (ORBit_poa_allow_cross_thread_call ((ORBit_POAObject) adaptor_obj,
+						       m_data->flags)) {
 			tprintf_header (obj, m_data);
 			tprintf ("[in-proc]");
 			ORBit_small_handle_request (adaptor_obj, m_data->name, ret,
@@ -614,6 +617,11 @@ ORBit_small_invoke_stub (CORBA_Object       obj,
 			goto clean_out;
 		} else {
 			tprintf ("[in-proc-XT]");
+			/*
+			 * FIXME: this is _really_ slow, can easily be optimised
+			 * by shoving the GIOP data straight on the incoming
+			 * queue
+			 */
 			xt_proxy = ORBit_objref_get_proxy (obj);
 			obj = xt_proxy;
 		}
@@ -1331,7 +1339,7 @@ ORBit_small_unlisten_for_broken_full (CORBA_Object obj,
 	else {
 		GIOPConnection *cnx;
 
-		cnx = ORBit_object_get_connection (obj);
+		cnx = ORBit_object_peek_connection (obj);
 
 		if (cnx) {
 			ret = get_status (cnx);
